==> calendar_link-8.x-1.0.tar.gz: calendar_link/README.md <==
CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Installation
 * Configuration
 * Use
 * Examples
 * Maintainers


INTRODUCTION
------------

Calendar links provides two Twig functions for generating links for various
calendaring services.


REQUIREMENTS
------------

This module does not require any additional modules outside of Drupal core.

This module uses the 
[spatie/calendar-links](https://packagist.org/packages/spatie/calendar-links)
library as its foundation. Use composer to install the module (see INSTALLATION)
or run `composer require spatie/calendar-links` separately.


INSTALLATION
------------

 * Install with composer to ensure dependencies are also installed: 
   `composer require 'drupal/calendar_link'`

 * Install as you would normally install a contributed Drupal module. See:
   https://drupal.org/documentation/install/modules-themes/modules-8
   for further information.


CONFIGURATION
-------------

There is no configuration available for this module.

USE
---

This module provides two new Twig functions for generating calendar link URLs:

1. `calendar_link`

Returns a string link for a specific calendar type. Available types are:

*. Apple iCal/Microsoft Outlook (`ics`)
*. Google calendar (`google`)
*. Outlook.com (`webOutlook`)
*. Yahoo! calendar (`yahoo`)

2. `calendar_links`

Returns an array of links for all available calendar types. Each array element
has the following keys/data:

*. `type_key`: The calendar type key (`ics`, `google`, etc.)
*. `type_name`: The calendar type name ("iCal", "Google", etc.)
*. `url`: The URL for the calendar item.


EXAMPLES
--------

Assume an example "Event" node with the extras fields:

*. Title (string `title`)
*. Start date/time (datetime `field_start`)
*. End date/time (datetime `field_end`)
*. All day event (boolean `field_all_day`)
*. Description (string `field_description`)
*. Location (string `field_location`)

In a twig template, the following code with generate a link to the event to a 
Google calendar:

```twig
{% set link = calendar_link('google', 
  title,
  field_start,
  field_end,
  field_all_day,
  field_description,
  field_location)
%}
<a href="{{ link }}">Add to Google</a>
```

Or, to create a list of links for each service:

```twig
{% set links = calendar_links(
  title,
  field_start,
  field_end,
  field_all_day,
  field_description,
  field_location)
%}
<ul>
{% for link in links %}
  <li>
    <a href="{{ link.url }}" 
       class="calendar-link-{{ link.type_key }}">{{ link.type_name }}</a>
  </li>
{% endfor %}
```


MAINTAINERS
-----------

Current maintainers:

 * [Christopher C. Wells (wells)](https://www.drupal.org/u/wells)

Development is sponsored by:

 * [Cascade Public Media](https://www.drupal.org/cascade-public-media)

==> calendar_link-8.x-1.1.tar.gz: calendar_link/README.md <==
CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Installation
 * Configuration
 * Use
 * Examples
 * Maintainers


INTRODUCTION
------------

Calendar links provides two Twig functions for generating links for various
calendaring services.


REQUIREMENTS
------------

This module does not require any additional modules outside of Drupal core.

This module uses the 
[spatie/calendar-links](https://packagist.org/packages/spatie/calendar-links)
library as its foundation. Use composer to install the module (see INSTALLATION)
or run `composer require spatie/calendar-links` separately.


INSTALLATION
------------

 * Install with composer to ensure dependencies are also installed: 
   `composer require 'drupal/calendar_link'`

 * Install as you would normally install a contributed Drupal module. See:
   https://drupal.org/documentation/install/modules-themes/modules-8
   for further information.


CONFIGURATION
-------------

There is no configuration available for this module.

USE
---

This module provides two new Twig functions for generating calendar link URLs:

1. `calendar_link`

Returns a string link for a specific calendar type. Available types are:

*. Apple iCal/Microsoft Outlook (`ics`)
*. Google calendar (`google`)
*. Outlook.com (`webOutlook`)
*. Yahoo! calendar (`yahoo`)

2. `calendar_links`

Returns an array of links for all available calendar types. Each array element
has the following keys/data:

*. `type_key`: The calendar type key (`ics`, `google`, etc.)
*. `type_name`: The calendar type name ("iCal", "Google", etc.)
*. `url`: The URL for the calendar item.


EXAMPLES
--------

Assume an example "Event" node with the extras fields:

*. Title (string `title`)
*. Start date/time (datetime `field_start`)
*. End date/time (datetime `field_end`)
*. All day event (boolean `field_all_day`)
*. Description (text_format `body`)
*. Location (string `field_location`)

In a twig template, the following code with generate a link to the event to a 
Google calendar:

```twig
{% set link = calendar_link('google', 
  node.title.value,
  node.field_start.date,
  node.field_end.date,
  node.field_all_day.value,
  node.body.value,
  node.field_location.value
)
%}
<a href="{{ link }}">Add to Google</a>
```

Or, to create a list of links for each service:

```twig
{% set links = calendar_links(
  node.title.value,
  node.field_start.date,
  node.field_end.date,
  node.field_all_day.value,
  node.body.value,
  node.field_location.value
)
%}
<ul>
{% for link in links %}
  <li>
    <a href="{{ link.url }}" 
       class="calendar-link-{{ link.type_key }}">{{ link.type_name }}</a>
  </li>
{% endfor %}
```


MAINTAINERS
-----------

Current maintainers:

 * [Christopher C. Wells (wells)](https://www.drupal.org/u/wells)

Development is sponsored by:

 * [Cascade Public Media](https://www.drupal.org/cascade-public-media)
